@@ -1535,14 +1535,13 @@ void connman_element_set_error(struct connman_element *element,
 	__connman_service_indicate_error(service, convert_error(error));
 }
 
-int __connman_element_init(DBusConnection *conn, const char *device,
-							const char *nodevice)
+int __connman_element_init(const char *device, const char *nodevice)
 {
 	struct connman_element *element;
 
-	DBG("conn %p", conn);
+	DBG("");
 
-	connection = dbus_connection_ref(conn);
+	connection = connman_dbus_get_connection();
 	if (connection == NULL)
 		return -EIO;
 
@@ -1584,7 +1583,7 @@ void __connman_element_start(void)
 {
 	DBG("");
 
-	__connman_storage_load_global();
+	__connman_storage_init_profile();
 
 	g_node_traverse(element_root, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
 							probe_node, NULL);
@@ -1606,8 +1605,6 @@ void __connman_element_stop(void)
 	__connman_rfkill_cleanup();
 	__connman_ipv4_cleanup();
 	__connman_connection_cleanup();
-
-	__connman_storage_save_global();
 }
 
 static gboolean free_driver(GNode *node, gpointer data)
@@ -1660,5 +1657,8 @@ void __connman_element_cleanup(void)
 
 	g_free(device_filter);
 
+	if (connection == NULL)
+		return;
+
 	dbus_connection_unref(connection);
 }
