@@ -30,6 +30,8 @@
 
 #include "connman.h"
 
+static unsigned int hidden_counter = 0;
+
 struct connman_network {
 	struct connman_element element;
 	enum connman_network_type type;
@@ -205,6 +207,9 @@ static DBusMessage *set_property(DBusConnection *conn,
 	} else if (g_str_has_prefix(name, "IPv4.") == TRUE) {
 		int err;
 
+		if (network->ipconfig == NULL)
+			return __connman_error_invalid_property(msg);
+
 		err = __connman_ipconfig_set_ipv4(network->ipconfig,
 							name + 5, &value);
 		if (err < 0)
@@ -368,7 +373,10 @@ static void network_destruct(struct connman_element *element)
 	g_free(network->address);
 	g_free(network->identifier);
 
-	connman_ipconfig_unref(network->ipconfig);
+	if (network->ipconfig) {
+		connman_ipconfig_unref(network->ipconfig);
+		network->ipconfig = NULL;
+	}
 }
 
 /**
@@ -399,7 +407,7 @@ struct connman_network *connman_network_create(const char *identifier,
 
 	//temp = connman_dbus_encode_string(identifier);
 	if (identifier == NULL) {
-		temp = g_strdup("hidden");
+		temp = g_strdup_printf("hidden_%d", hidden_counter++);
 		network->hidden = TRUE;
 	} else
 		temp = g_strdup(identifier);
@@ -425,12 +433,6 @@ struct connman_network *connman_network_create(const char *identifier,
 	network->secondary  = FALSE;
 	network->identifier = g_strdup(temp);
 
-	network->ipconfig = connman_ipconfig_create();
-	if (network->ipconfig == NULL) {
-		connman_network_unref(network);
-		return NULL;
-	}
-
 	return network;
 }
 
@@ -549,9 +551,9 @@ void connman_network_set_group(struct connman_network *network,
 	switch (network->type) {
 	case CONNMAN_NETWORK_TYPE_UNKNOWN:
 	case CONNMAN_NETWORK_TYPE_VENDOR:
+		return;
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-		return;
 	case CONNMAN_NETWORK_TYPE_MBM:
 	case CONNMAN_NETWORK_TYPE_HSO:
 	case CONNMAN_NETWORK_TYPE_WIFI:
@@ -1245,9 +1247,9 @@ static int network_probe(struct connman_element *element)
 	switch (network->type) {
 	case CONNMAN_NETWORK_TYPE_UNKNOWN:
 	case CONNMAN_NETWORK_TYPE_VENDOR:
+		break;
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-		break;
 	case CONNMAN_NETWORK_TYPE_MBM:
 	case CONNMAN_NETWORK_TYPE_HSO:
 	case CONNMAN_NETWORK_TYPE_WIFI:
@@ -1275,9 +1277,9 @@ static void network_remove(struct connman_element *element)
 	switch (network->type) {
 	case CONNMAN_NETWORK_TYPE_UNKNOWN:
 	case CONNMAN_NETWORK_TYPE_VENDOR:
+		break;
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_PAN:
 	case CONNMAN_NETWORK_TYPE_BLUETOOTH_DUN:
-		break;
 	case CONNMAN_NETWORK_TYPE_MBM:
 	case CONNMAN_NETWORK_TYPE_HSO:
 	case CONNMAN_NETWORK_TYPE_WIFI:
